<?xml version = '1.0'?>
<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui version="52" name="Konqueror" >
 <MenuBar>
  <Menu noMerge="1" name="file" >
   <text>&amp;Location</text>
   <Action name="new_window" />
   <Action name="newtab" />
   <Action name="open_location" />
   <Separator/>
   <Action name="sendURL" />
   <Action name="sendPage" />
   <Separator/>
   <Merge/>
   <Action name="print" />
   <DefineGroup name="print" />
   <Separator/>
   <ActionList name="openwith" />
   <Action name="quit" />
  </Menu>
  <Menu noMerge="1" name="edit" >
   <text>&amp;Edit</text>
   <Action name="copy" />
   <Action name="paste" />
   <Action name="del" />
   <ActionList name="operations" />
   <Separator/>
   <Action name="properties" />
   <WeakSeparator/>
   <Merge/>
  </Menu>
  <Menu noMerge="1" name="view" >
   <text>&amp;View</text>
   <Action name="go_most_often" />
   <ActionList name="viewmode" />
   <Separator/>
   <Merge/>
  </Menu>
  <Action name="bookmarks" />
  <Menu name="tools" >
   <text>&amp;Tools</text>
   <WeakSeparator/>
   <Merge/>
  </Menu>
  <Menu noMerge="1" name="settings" >
   <text>&amp;Settings</text>
   <Merge name="StandardToolBarMenuHandler" />
   <Action name="saveviewprofile" />
   <Action name="options_show_menubar" />
   <Action name="fullscreen" />
   <Separator/>
   <Action name="options_configure_keybinding" />
   <Action name="options_configure_toolbars" />
   <Action name="options_configure_extensions" />
   <Action name="options_configure" />
   <Action name="configurespellcheck" />
  </Menu>
  <Menu append="about_merge" name="help" >
   <text>&amp;Help</text>
   <Action name="konqintro" />
  </Menu>
  <Merge/>
 </MenuBar>
 <ToolBar newline="true" hidden="true" name="mainToolBar">
  <text>Main Toolbar</text>
  <Action name="konq_sidebartng" />
  <Separator name="separator_0" />
  <Action name="print" />
  <WeakSeparator/>
  <Merge/>
  <ActionList name="viewmode_toolbar" />
  <ActionList name="fullscreen" />
  <WeakSeparator/>
 </ToolBar>
 <ToolBar newline="false" hidden="true" index="1" name="extraToolBar" >
  <text>Extra Toolbar</text>
 </ToolBar>
 <ToolBar newline="true" noMerge="1" name="locationToolBar" fullWidth="true" >
  <text>Location Toolbar</text>
  <Action name="back" />
  <Action name="forward" />
  <Action name="up" />
  <Action name="home" />
  <Action name="reload" />
  <Action name="stop" />
  <Action name="security" />
  <Action name="clear_location" />
  <Action name="location_label" />
  <Action name="toolbar_url_combo" />
  <Action name="go_url" />
  <Action name="animated_logo" />
 </ToolBar>
 <ToolBar newline="true" noEdit="true" iconText="icontextright" name="bookmarkToolBar" fullWidth="true" >
  <text>Bookmark Toolbar</text>
 </ToolBar>
 <ActionProperties>
  <Action shortcut="F9" name="konq_sidebartng" />
 </ActionProperties>
</gui>
