# Save old config files:
if [ ! -L etc/X11/kdm ]; then
  if [ -d etc/X11/kdm ]; then
    mkdir -p etc/kde/kdm
    cp -a etc/X11/kdm/* etc/kde/kdm
    rm -rf etc/X11/kdm
    ( cd etc/X11 ; ln -sf /etc/kde/kdm kdm )
  fi
elif [ ! -e etc/X11/kdm ]; then
  mkdir -p etc/X11
  ( cd etc/X11 ; ln -sf /etc/kde/kdm kdm )
fi

#!/bin/sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/kde/kdm/kdmrc.new
config etc/kde/kdm/backgroundrc.new

( cd usr/bin ; rm -rf kinfocenter )
( cd usr/bin ; ln -sf kcontrol kinfocenter )
( cd usr/lib ; rm -rf libkickermain.so.1 )
( cd usr/lib ; ln -sf libkickermain.so.1.0.0 libkickermain.so.1 )
( cd usr/lib ; rm -rf libkdecorations.so.1 )
( cd usr/lib ; ln -sf libkdecorations.so.1.0.0 libkdecorations.so.1 )
( cd usr/lib ; rm -rf libkonqsidebarplugin.so.1 )
( cd usr/lib ; ln -sf libkonqsidebarplugin.so.1.2.0 libkonqsidebarplugin.so.1 )
( cd usr/lib ; rm -rf libkateutils.so )
( cd usr/lib ; ln -sf libkateutils.so.0.0.0 libkateutils.so )
( cd usr/lib ; rm -rf libkateinterfaces.so.0 )
( cd usr/lib ; ln -sf libkateinterfaces.so.0.0.0 libkateinterfaces.so.0 )
( cd usr/lib ; rm -rf libkonqsidebarplugin.so )
( cd usr/lib ; ln -sf libkonqsidebarplugin.so.1.2.0 libkonqsidebarplugin.so )
( cd usr/lib ; rm -rf libkonq.so.4 )
( cd usr/lib ; ln -sf libkonq.so.4.2.0 libkonq.so.4 )
( cd usr/lib ; rm -rf libksplashthemes.so.0 )
( cd usr/lib ; ln -sf libksplashthemes.so.0.0.0 libksplashthemes.so.0 )
( cd usr/lib ; rm -rf libkateutils.so.0 )
( cd usr/lib ; ln -sf libkateutils.so.0.0.0 libkateutils.so.0 )
( cd usr/lib ; rm -rf libkhotkeys_shared.so.1 )
( cd usr/lib ; ln -sf libkhotkeys_shared.so.1.0.0 libkhotkeys_shared.so.1 )
( cd usr/lib ; rm -rf libksgrd.so )
( cd usr/lib ; ln -sf libksgrd.so.1.2.0 libksgrd.so )
( cd usr/lib ; rm -rf libkickermain.so )
( cd usr/lib ; ln -sf libkickermain.so.1.0.0 libkickermain.so )
( cd usr/lib ; rm -rf libtaskmanager.so )
( cd usr/lib ; ln -sf libtaskmanager.so.1.0.0 libtaskmanager.so )
( cd usr/lib ; rm -rf libkasbar.so )
( cd usr/lib ; ln -sf libkasbar.so.1.0.0 libkasbar.so )
( cd usr/lib ; rm -rf libkfontinst.so )
( cd usr/lib ; ln -sf libkfontinst.so.0.0.0 libkfontinst.so )
( cd usr/lib ; rm -rf libksgrd.so.1 )
( cd usr/lib ; ln -sf libksgrd.so.1.2.0 libksgrd.so.1 )
( cd usr/lib ; rm -rf libtaskbar.so.1 )
( cd usr/lib ; ln -sf libtaskbar.so.1.2.0 libtaskbar.so.1 )
( cd usr/lib ; rm -rf libkfontinst.so.0 )
( cd usr/lib ; ln -sf libkfontinst.so.0.0.0 libkfontinst.so.0 )
( cd usr/lib ; rm -rf libtaskmanager.so.1 )
( cd usr/lib ; ln -sf libtaskmanager.so.1.0.0 libtaskmanager.so.1 )
( cd usr/lib ; rm -rf libkasbar.so.1 )
( cd usr/lib ; ln -sf libkasbar.so.1.0.0 libkasbar.so.1 )
( cd usr/lib ; rm -rf libkhotkeys_shared.so )
( cd usr/lib ; ln -sf libkhotkeys_shared.so.1.0.0 libkhotkeys_shared.so )
( cd usr/lib ; rm -rf libtaskbar.so )
( cd usr/lib ; ln -sf libtaskbar.so.1.2.0 libtaskbar.so )
( cd usr/lib ; rm -rf libkateinterfaces.so )
( cd usr/lib ; ln -sf libkateinterfaces.so.0.0.0 libkateinterfaces.so )
( cd usr/lib ; rm -rf libkonq.so )
( cd usr/lib ; ln -sf libkonq.so.4.2.0 libkonq.so )
( cd usr/lib ; rm -rf libkdecorations.so )
( cd usr/lib ; ln -sf libkdecorations.so.1.0.0 libkdecorations.so )
( cd usr/lib ; rm -rf libksplashthemes.so )
( cd usr/lib ; ln -sf libksplashthemes.so.0.0.0 libksplashthemes.so )
( cd usr/share/doc/HTML/en/kdm ; rm -rf common )
( cd usr/share/doc/HTML/en/kdm ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kate ; rm -rf common )
( cd usr/share/doc/HTML/en/kate ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kxkb ; rm -rf common )
( cd usr/share/doc/HTML/en/kxkb ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksysguard ; rm -rf common )
( cd usr/share/doc/HTML/en/ksysguard ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kdcop ; rm -rf common )
( cd usr/share/doc/HTML/en/kdcop ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kdesu ; rm -rf common )
( cd usr/share/doc/HTML/en/kdesu ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kfind ; rm -rf common )
( cd usr/share/doc/HTML/en/kfind ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/klipper ; rm -rf common )
( cd usr/share/doc/HTML/en/klipper ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kompmgr ; rm -rf common )
( cd usr/share/doc/HTML/en/kompmgr ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/konsole ; rm -rf common )
( cd usr/share/doc/HTML/en/konsole ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/khelpcenter/faq ; rm -rf common )
( cd usr/share/doc/HTML/en/khelpcenter/faq ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/khelpcenter/quickstart ; rm -rf common )
( cd usr/share/doc/HTML/en/khelpcenter/quickstart ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/khelpcenter/glossary ; rm -rf common )
( cd usr/share/doc/HTML/en/khelpcenter/glossary ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/khelpcenter ; rm -rf common )
( cd usr/share/doc/HTML/en/khelpcenter ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/khelpcenter/userguide ; rm -rf common )
( cd usr/share/doc/HTML/en/khelpcenter/userguide ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/khelpcenter/visualdict ; rm -rf common )
( cd usr/share/doc/HTML/en/khelpcenter/visualdict ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kmenuedit ; rm -rf common )
( cd usr/share/doc/HTML/en/kmenuedit ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kioslave ; rm -rf common )
( cd usr/share/doc/HTML/en/kioslave ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/knetattach ; rm -rf common )
( cd usr/share/doc/HTML/en/knetattach ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/kdm ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kdm ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/smb ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/smb ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/spellchecking ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/spellchecking ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/bell ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/bell ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/arts ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/arts ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/keys ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/keys ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/cookies ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/cookies ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/filetypes ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/filetypes ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/desktop ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/desktop ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/cache ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/cache ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/clock ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/clock ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/email ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/email ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/fonts ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/fonts ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/icons ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/icons ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/khtml ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/khtml ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/filemanager ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/filemanager ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/mouse ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/mouse ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/panel ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/panel ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/proxy ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/proxy ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/desktopbehavior ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/desktopbehavior ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/passwords ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/passwords ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/panelappearance ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/panelappearance ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/ebrowsing ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/ebrowsing ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/helpindex.html ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/helpindex.html ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/background ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/background ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/kcmaccess ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kcmaccess ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/colors ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/colors ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/crypto ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/crypto ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/energy ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/energy ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/kcmstyle ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kcmstyle ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/netpref ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/netpref ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/kcmlaunch ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kcmlaunch ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/kcmcss ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kcmcss ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/kcmnotify ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kcmnotify ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/kcmsmserver ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kcmsmserver ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/screensaver ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/screensaver ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/windowmanagement ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/windowmanagement ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/kwindecoration ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kwindecoration ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/kcmkonsole ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kcmkonsole ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/language ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/language ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/useragent ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/useragent ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/keyboard ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/keyboard ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/kcmtaskbar ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kcmtaskbar ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/kcmfontinst ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/kcmfontinst ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcontrol/performance ; rm -rf common )
( cd usr/share/doc/HTML/en/kcontrol/performance ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kdeprint ; rm -rf common )
( cd usr/share/doc/HTML/en/kdeprint ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kicker ; rm -rf common )
( cd usr/share/doc/HTML/en/kicker ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kpager ; rm -rf common )
( cd usr/share/doc/HTML/en/kpager ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kwrite ; rm -rf common )
( cd usr/share/doc/HTML/en/kwrite ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/ksplashml ; rm -rf common )
( cd usr/share/doc/HTML/en/ksplashml ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kdebugdialog ; rm -rf common )
( cd usr/share/doc/HTML/en/kdebugdialog ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/dma ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/dma ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/pci ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/pci ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/usb ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/usb ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/nics ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/nics ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/scsi ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/scsi ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/interrupts ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/interrupts ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/devices ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/devices ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/xserver ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/xserver ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/samba ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/samba ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/sound ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/sound ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/partitions ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/partitions ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/cdinfo ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/cdinfo ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/memory ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/memory ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/pcmcia ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/pcmcia ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/opengl ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/opengl ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/processor ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/processor ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/ioports ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/ioports ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/protocols ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/protocols ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/konqueror ; rm -rf common )
( cd usr/share/doc/HTML/en/konqueror ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/config ; rm -rf kdm )
( cd usr/share/config ; ln -sf ../../../etc/kde/kdm kdm )
