<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kwrite" version="16">

<MenuBar>
  <Menu name="file" noMerge="1"><text>&amp;File</text>
    <Action name="file_new"/>
    <Separator/>

    <Action name="file_open"/>
    <Action name="file_open_recent"/>
    <Separator/>

    <DefineGroup name="save_merge" append="save_merge" />
    <Separator/>

    <DefineGroup name="revert_merge" append="revert_merge"/>
    <DefineGroup name="print_merge" append="print_merge"/>
    <Separator/>

    <Action name="file_close"/>
    <DefineGroup name="close_merge" append="close_merge"/>
    <Separator/>

    <Action name="file_quit"/>
  </Menu>

  <Menu name="edit" noMerge="1"><text>&amp;Edit</text>
    <DefineGroup name="edit_undo_merge"/>
    <Separator/>
    <DefineGroup name="edit_paste_merge"/>
    <Separator/>
    <DefineGroup name="edit_select_merge"/>
    <Separator/>
    <DefineGroup name="edit_find_merge"/>
    <Separator/>
    <Merge/>
  </Menu>

  <Menu name="view" noMerge="1"><text>&amp;View</text>
    <Action name="view_new_view" />
    <Separator />
    <DefineGroup name="view_operations" />
  </Menu>

  <Menu name="tools" noMerge="1"><text>&amp;Tools</text>
    <DefineGroup name="tools_operations" />
  </Menu>

  <Merge/>

  <Menu name="settings"><text>&amp;Settings</text>
    <Merge name="StandardToolBarMenuHandler" />
    <DefineGroup name="show_toolbar_merge" />
    <Action name="settings_show_statusbar" append="show_merge"/>
    <Action name="set_showPath" append="show_merge"/>
    <DefineGroup name="show_merge" />
    <DefineGroup name="configure_merge" append="save_merge"/>
    <Action name="options_configure_toolbars" />
    <Action name="settings_configure" append="configure_merge"/>
    <Action name="settings_choose_editor" append="save_merge"/>
  </Menu>

  <Menu name="help" noMerge="1"><text>&amp;Help</text>
    <Action name="help_contents"/>
    <Action name="help_whats_this"/>
    <Separator/>
    <Action name="help_report_bug"/>
    <Separator/>
    <Action name="help_about_app"/>
    <Action name="help_about_kde"/>
  </Menu>
</MenuBar>

<ToolBar name="mainToolBar" noMerge="1"><text>Main Toolbar</text>
  <Action name="file_new" />
  <Action name="file_open" />
  <Separator />
  <DefineGroup name="file_operations" />
  <Separator />
  <DefineGroup name="print_merge" />
  <Separator />
  <Action name="file_close" />
  <Separator />
  <DefineGroup name="edit_operations" />
  <Separator />
  <DefineGroup name="find_operations" />
  <Separator />
  <DefineGroup name="zoom_operations" />
</ToolBar>

<Menu name="ktexteditor_popup" noMerge="1">
  <DefineGroup name="popup_operations" />
</Menu>

</kpartgui>
