BODY {
	color: #FFFFCC;
	background-color: #000000;
	padding: 2em;
	margin: auto;
}
	
A:link {color: #82A7D0}
A:visited {color: #999999}
A:active {color: #999999}

H1 {
	color: #999999;
	background-color: #000000;	
	font: 200% Helvetica, sans-serif; 
	font-variant: normal; 
	padding: 1em;
	margin: auto;
}
	
.mainTable {
	background-color: #000000;
	border: thin solid;
	margin: auto;
}
	

.courierText {
	color: #FFFFCC;
	background-color: #000000;	
	font: 120% Courier, sans-serif;
	font-variant: normal; 
	text-align: left;
	padding: 0em;
}

.commandText {
	color: #FFFFCC;
	background-color: #000000;	
	font: 120% Courier, sans-serif;
	font-variant: normal; 
	text-align: center;
	padding: 0.5em;
}

.niceText {
	color: #009999;
	background-color: #000000;	
	font: 120% Arial, sans-serif; 
	font-variant: normal; 
	text-align: center;
	padding: 0.5em;
}

.finger		{ color: #82A7D0}
.domainName	{ color: #D0A000}
.ipNumber       { color: #D0A000}
.os 		{ color: #82A7D0}
.username 	{ color: #82A7D0}
.directory	{ color: #D0A000}
.shell 		{ color: #D0A000}
.notLoggedIn 	{ color: #00A000}
.loggedIn 	{ color: #B00000}
.newMail	{ color: #82A7D0}
.plan		{ color: #D0A000}
.noNewMail 	{ color: #BB0000}
.noPlan 	{ color: #BB0000}

	
