<!DOCTYPE kpartgui>
<kpartgui name="kdeprint_part">
<ToolBar name="Kdeprint-Toolbar" newline="false"><text>Print Manager Toolbar</text>
  <Action name="printer_add" />
  <Action name="printer_add_special" />
  <Separator lineSeparator="true" />
  <Action name="printer_state_change" />
  <Action name="printer_spool_change" />
  <Separator />
  <Action name="printer_hard_default" />
  <Action name="printer_soft_default" />
  <Action name="printer_remove" />
  <Separator />
  <Action name="printer_configure" />
  <Action name="printer_test" />
  <Separator lineSeparator="true" />
  <Action name="server_configure" />
  <Action name="server_restart" />
  <Separator lineSeparator="true" />
  <Action name="manager_configure" />
  <Action name="view_refresh" />
  <Separator lineSeparator="true" />
  <Action name="view_printerinfos" />
  <Action name="view_change" />
  <Action name="orientation_change" />
  <Action name="view_pfilter" />
</ToolBar>
</kpartgui>
