# Default KSplash/ML Theme

[KSplash Theme: default]
Name = KDE 3.5 Splash Screen
Description = Waves of change
Version = 1.0
Author = Lee Olson <clearbeast@gmail.com>

# Theme behaviour settings.
Engine = Default

# Should icons blink ala KDE, or not?
Icons Flashing = true

# Show progress bar?
Always Show Progress = false

# Status text colour
Label Foreground = #FFFFFF
