td.main { background-color: #505050;}
td.logo { background-color: #DDDDDD;}
td.lines { background-color: #DDDDDD;
           background-image: url(lines.png);}
td.trans { background-repeat: no-repeat;}
td.end { background-image: url(lines2.png);
         background-repeat: x-repeat;}
td.shadow1 { background-image: url(shadow1.png);
             background-repeat: x-repeat;}
tr.top { font-family: sans-serif;
              color: #ffffff;
              background-color: #505050}
tr.contentyellow { font-family: sans-serif;
                   color: #000000;
                   background-color: #fff4c9}
tr.contentwhite { font-family: sans-serif;
                  color: #000000;
                  background-color: #FFFFFF}
tr.menurow {background-color: #505050;
            color: #000000;
            vertical-align: middle;}
td.deco      {color: #ffffff;
             background-color: #505050;
             font-family: sans-serif;
             font-size: small;}
td.menuactive      {color: #ffcc00;
             background-color: #777777;
             font-family: sans-serif;
             font-size: small;}
td.menu      {color: #ffffff;
             background-color: #505050;
             font-family: sans-serif;}
a.menu 	    {color: #eeeeee;
            font-family: sans-serif;
            font-size: small;}
a.menu:hover {color: #ffffff;
              text-decoration: none;}

