<!DOCTYPE kpartgui>
<kpartgui name="ksysguard" version="5">
<State name="showProcessState">
  <Disable>
    <Action name="new_worksheet"/>
    <Action name="import_worksheet"/>
    <Action name="recent_import_worksheet"/>
    <Action name="export_worksheet"/>
    <Action name="remove_worksheet"/>
    <Action name="revert_all_worksheets"/>
    <Action name="connect_host"/>
    <Action name="disconnect_host"/>
    <Action name="configure_sheet"/>
    <Action name="configure_style"/>
  </Disable>
</State>
<MenuBar>
  <Menu name="file"><text>&amp;File</text>
    <Action name="new_worksheet"/>
    <Action name="recent_import_worksheet"/>
    <Action name="import_worksheet"/>
    <Separator/>
    <Action name="export_worksheet"/>
    <Separator/>
    <Action name="remove_worksheet"/>
    <Action name="revert_all_worksheets"/>
    <Separator/>
    <Action name="connect_host"/>
    <Action name="disconnect_host"/>
  </Menu>
  <Menu name="edit"><text>&amp;Edit</text>
    <Action name="configure_sheet"/>
  </Menu>
  <Menu name="settings"><text>&amp;Settings</text>
    <Action name="configure_style"/>
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar" noMerge="1"><text>Main Toolbar</text>
    <Action name="new_worksheet"/>
    <Action name="import_worksheet"/>
    <Action name="export_worksheet"/>
    <Separator/>
    <Action name="connect_host"/>
    <Action name="disconnect_host"/>
    <Separator/>
    <Action name="configure_sheet"/>
    <Action name="configure_style"/>
</ToolBar>
</kpartgui>

